@@ -23,9 +23,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <pds/pdsra.h>
-#include <pds/pdsca.h>
 #include <pds/pdsoctplotpng.h>
 
+#define FONTSIZE 18
 
 /** \fn int pds_octplot_surf_matrix_in_png(const PdsMatrix *M,const char *labelx,const char *labely,const char *labelz,const char *octfile,const char *pngfile)
  *  \brief Imprime una matriz M en un archivo png usando como intermedio un 
@@ -35,6 +35,8 @@
  *  \param[in] labely Etiqueta del eje Y: Lineas.
  *  \param[in] labelz Etiqueta del eje Z: Altura.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -49,10 +51,24 @@ int pds_octplot_surf_matrix_in_png(const PdsMatrix *M,const char *labelx,const c
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
 	if(labelz==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"M=[");
 	for(i=0 ; i<M->Nlin ; i++)	
@@ -69,16 +85,25 @@ int pds_octplot_surf_matrix_in_png(const PdsMatrix *M,const char *labelx,const c
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
 	fprintf(fd,"zlabel(\'%s\');\n",labelz);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -91,6 +116,8 @@ int pds_octplot_surf_matrix_in_png(const PdsMatrix *M,const char *labelx,const c
  *  \param[in] labely Etiqueta del eje Y: Lineas.
  *  \param[in] labelz Etiqueta del eje Z: Altura.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -105,10 +132,22 @@ int pds_octplot_pcolor_matrix_in_png(const PdsMatrix *M,const char *labelx,const
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
 	if(labelz==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"M=[");
 	for(i=0 ; i<M->Nlin ; i++)	
@@ -125,16 +164,25 @@ int pds_octplot_pcolor_matrix_in_png(const PdsMatrix *M,const char *labelx,const
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
 	fprintf(fd,"zlabel(\'%s\');\n",labelz);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -147,6 +195,8 @@ int pds_octplot_pcolor_matrix_in_png(const PdsMatrix *M,const char *labelx,const
  *  \param[in] labely Etiqueta del eje Y: Lineas.
  *  \param[in] labelz Etiqueta del eje Z: Altura.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -161,10 +211,24 @@ int pds_octplot_image_matrix_in_png(const PdsMatrix *M,const char *labelx,const
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
 	if(labelz==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"M=[");
 	for(i=0 ; i<M->Nlin ; i++)	
@@ -181,16 +245,25 @@ int pds_octplot_image_matrix_in_png(const PdsMatrix *M,const char *labelx,const
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
 	fprintf(fd,"zlabel(\'%s\');\n",labelz);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -202,6 +275,8 @@ int pds_octplot_image_matrix_in_png(const PdsMatrix *M,const char *labelx,const
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -215,30 +290,54 @@ int pds_octplot_vector_in_png(const PdsVector *V,const char *labelx,const char *
 	if(V==NULL)		return FALSE;
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"V=[");
 	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i]);
 	fprintf(fd,"];\n");
 	fprintf(fd,"N=length(V);\n");
-	fprintf(fd,"EjeX=[0:N-1];\n");
-	fprintf(fd,"plot(EjeX,V,\'o-\');\n");
+	fprintf(fd,"X=[0:N-1];\n");
+	fprintf(fd,"plot(X,V,\'o-\');\n");
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -247,10 +346,14 @@ int pds_octplot_vector_in_png(const PdsVector *V,const char *labelx,const char *
  *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
  *  archivo *.m de octave.
  *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
  *  \param[in] Y Eje Y del vector a imprimir.
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -261,302 +364,168 @@ int pds_octplot_vectors_in_png(const PdsVector *X,const PdsVector *Y,const char
 	FILE *fd=NULL;
 	char *orden=NULL;
 
-	if(X==NULL)		return FALSE;
 	if(Y==NULL)		return FALSE;
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
-	if(X->Nel!=Y->Nel)	return FALSE;
+    if(X!=NULL)	if(X->Nel!=Y->Nel)	return FALSE;
 
-	fd=fopen(octfile,"w");
+
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
-	fprintf(fd,"X=[");
-	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
-	fprintf(fd,"];\n");
 	fprintf(fd,"Y=[");
 	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i]);
 	fprintf(fd,"];\n");
+    if(X==NULL)
+    {
+	    fprintf(fd,"N=length(Y);\n");
+	    fprintf(fd,"X=[0:N-1];\n");
+    }
+    else
+    {
+	    fprintf(fd,"X=[");
+    	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
+    	fprintf(fd,"];\n");
+    }
 	fprintf(fd,"plot(X,Y,\'o-\');\n");
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
 
-/** \fn int pds_octplot_cvector_in_png(const PdsCVector *V,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
- *  \brief Imprime un vector complejo V en un archivo png usando como intermedio un 
- *  archivo *.m de octave.
- *  \param[in] V Vector complejo a imprimir.
- *  \param[in] labelx Etiqueta del eje X.
- *  \param[in] labely Etiqueta del eje Y.
- *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  \param[in] pngfile Nombre del archivo *.png de salida.
- *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
- *  \ingroup PdsOctPlotPngGroup
- */
-int pds_octplot_cvector_in_png(const PdsCVector *V,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
-{
-	int i;
-	FILE *fd=NULL;
-	char *orden=NULL;
-
-	if(V==NULL)		return FALSE;
-	if(labelx==NULL)	return FALSE;
-	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
-	if(pngfile==NULL)	return FALSE;
-
-	fd=fopen(octfile,"w");
-	if(fd==NULL)		return FALSE;
-	fprintf(fd,"Vreal=[");
-	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i].Real);
-	fprintf(fd,"];\n");
-	fprintf(fd,"Nreal=length(Vreal);\n");
-	fprintf(fd,"EjeXreal=[0:Nreal-1];\n");
-	fprintf(fd,"Vimag=[");
-	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i].Imag);
-	fprintf(fd,"];\n");
-	fprintf(fd,"Nimag=length(Vimag);\n");
-	fprintf(fd,"EjeXimag=[0:Nimag-1];\n");
-	fprintf(fd,"plot(EjeXreal,Vreal,\'o-\',EjeXimag,Vimag,\'o-\');\n");
-	fprintf(fd,"grid on;\n");
-	fprintf(fd,"xlabel(\'%s\');\n",labelx);
-	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"legend('Real','Imag');\n");
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
-	fprintf(fd,"\n");
-	fprintf(fd,"\n");
-	fclose(fd);
-
-	orden=(char *)calloc(1,16+strlen(octfile));
-	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
-	i=system(orden);
-
-	return TRUE;
-}
-
-
-/** \fn int pds_octplot_cvectors_in_png(const PdsVector *X,const PdsCVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
- *  \brief Imprime un vector complejo Y vs el vector real X en un archivo png 
- *  usando como intermedio un archivo *.m de octave.
- *  \param[in] X Eje X del vector real a imprimir.
- *  \param[in] Y Eje Y del vector complejo a imprimir.
- *  \param[in] labelx Etiqueta del eje X.
- *  \param[in] labely Etiqueta del eje Y.
- *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  \param[in] pngfile Nombre del archivo *.png de salida.
- *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
- *  \ingroup PdsOctPlotPngGroup
- */
-int pds_octplot_cvectors_in_png(const PdsVector *X,const PdsCVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
-{
-	int i;
-	FILE *fd=NULL;
-	char *orden=NULL;
-
-	if(X==NULL)		return FALSE;
-	if(Y==NULL)		return FALSE;
-	if(labelx==NULL)	return FALSE;
-	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
-	if(pngfile==NULL)	return FALSE;
-	if(X->Nel!=Y->Nel)	return FALSE;
-
-	fd=fopen(octfile,"w");
-	if(fd==NULL)		return FALSE;
-	fprintf(fd,"X=[");
-	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
-	fprintf(fd,"];\n");
-	fprintf(fd,"Yreal=[");
-	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i].Real);
-	fprintf(fd,"];\n");
-	fprintf(fd,"Yimag=[");
-	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i].Imag);
-	fprintf(fd,"];\n");
-	fprintf(fd,"plot(X,Yreal,\'o-\',X,Yimag,\'o-\');\n");
-	fprintf(fd,"grid on;\n");
-	fprintf(fd,"xlabel(\'%s\');\n",labelx);
-	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"legend(\'Real\',\'Imag\');\n");
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
-	fprintf(fd,"\n");
-	fprintf(fd,"\n");
-	fclose(fd);
-
-	orden=(char *)calloc(1,16+strlen(octfile));
-	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
-	i=system(orden);
-
-	return TRUE;
-}
-
-
-/** \fn int pds_octplot_vector_compare_in_png(const PdsVector *U,const PdsVector *V,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+/** \fn int pds_octplot_compare_vectors_in_png(const PdsVector *X,const PdsVector *U,const PdsVector *V,const char *labelx,const char *labely,const char *legendu,const char *legendv,const char *octfile,const char *pngfile)
  *  \brief Imprime un vector U y V en un archivo png usando como intermedio un 
  *  archivo *.m de octave.
+ *  \param[in] X Vector correspondiente a el eje X de los vectores U y V.
+ *  Si X==NULL entonces se mostrara la comparación usando el numero de muestras
+ *  como eje X.
  *  \param[in] U Vector a imprimir.
  *  \param[in] V Vector a imprimir.
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] legendu Legenda de U.
+ *  \param[in] legendv Legenda de V.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
  */
-int pds_octplot_vector_compare_in_png(const PdsVector *U,const PdsVector *V,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+int pds_octplot_compare_vectors_in_png(const PdsVector *X,const PdsVector *U,const PdsVector *V,const char *labelx,const char *labely,const char *legendu,const char *legendv,const char *octfile,const char *pngfile)
 {
 	int i;
 	FILE *fd=NULL;
 	char *orden=NULL;
 
+	if(U==NULL)		return FALSE;
 	if(V==NULL)		return FALSE;
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
-	//if(U->Nel!=V->Nel)	return FALSE;
+	if(U->Nel!=V->Nel)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    if(X!=NULL)
+	if(X->Nel!=V->Nel)	return FALSE;
+
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"U=[");
 	for(i=0 ; i<U->Nel ; i++)	fprintf(fd,"%e\t",U->V[i]);
 	fprintf(fd,"];\n");
-	fprintf(fd,"Nu=length(U);\n");
-	fprintf(fd,"EjeXu=[0:Nu-1];\n");
 	fprintf(fd,"V=[");
 	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i]);
 	fprintf(fd,"];\n");
-	fprintf(fd,"Nv=length(V);\n");
-	fprintf(fd,"EjeXv=[0:Nv-1];\n");
-	fprintf(fd,"plot(EjeXu,U,\'o-\',EjeXv,V,\'o-\');\n");
+    if(X==NULL)
+    {
+	    fprintf(fd,"N=length(V);\n");
+	    fprintf(fd,"X=[0:N-1];\n");
+    }
+    else
+    {
+	    fprintf(fd,"X=[");
+    	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
+    	fprintf(fd,"];\n");
+    }
+	fprintf(fd,"plot(X,U,\'o-\',X,V,\'o-\');\n");
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"legend(\'First Vector\',\'Second Vector\');\n");
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+	fprintf(fd,"legend(\'%s\',\'%s\');\n",legendu,legendv);
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
-	return TRUE;
-}
-
-
-/** \fn int pds_octplot_afft_vector_in_png(const PdsVector *V,const char *labely,const char *octfile,const char *pngfile)
- *  \brief Imprime el valor absoluto de la FFT de un vector V en un archivo png 
- *  usando como intermedio un archivo *.m de octave.
- *  Imprime el valor absoluto de la FFT de V con 'o'.
- *  \param[in] V Vector a imprimir.
- *  \param[in] labely Etiqueta del eje Y.
- *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  \param[in] pngfile Nombre del archivo *.png de salida.
- *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
- *  \ingroup PdsOctPlotPngGroup
- */
-int pds_octplot_afft_vector_in_png(const PdsVector *V,const char *labely,const char *octfile,const char *pngfile)
-{
-	int i;
-	FILE *fd=NULL;
-	char *orden=NULL;
-
-	if(V==NULL)		return FALSE;
-	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
-	if(pngfile==NULL)	return FALSE;
-
-	fd=fopen(octfile,"w");
-	if(fd==NULL)		return FALSE;
-	fprintf(fd,"Y1=[");
-	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i]);
-	fprintf(fd,"];\n");
-	fprintf(fd,"N=%d;\n",V->Nel);
-	fprintf(fd,"X1=[0:N-1]*2/N;\n");
-	fprintf(fd,"F1=abs(fft(Y1));\n");
-	fprintf(fd,"plot(X1,F1,\'o-\');\n");
-	fprintf(fd,"grid on;\n");
-	fprintf(fd,"xlabel(\'[0 -> 2*pi]\');\n");
-	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
-	fprintf(fd,"\n");
-	fprintf(fd,"\n");
-	fclose(fd);
-
-	orden=(char *)calloc(1,16+strlen(octfile));
-	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
-	i=system(orden);
-
-	return TRUE;
-}
-
-
-/** \fn int pds_octplot_afft_vector8_in_png(const PdsVector *V,const char *labely,const char *octfile,const char *pngfile)
- *  \brief Imprime el valor absoluto de la FFT de un vector V en un archivo png 
- *  usando como intermedio un archivo *.m de octave.
- *  Imprime el valor absoluto de la FFT de V con 'o' y además el valor absoluto 
- *  de la FFT de V8=[V,0*V,0*V,0*V,0*V,0*V,0*V,0*V] con '--'.
- *  \param[in] V Vector a imprimir.
- *  \param[in] labely Etiqueta del eje Y.
- *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  \param[in] pngfile Nombre del archivo *.png de salida.
- *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
- *  \ingroup PdsOctPlotPngGroup
- */
-int pds_octplot_afft_vector8_in_png(const PdsVector *V,const char *labely,const char *octfile,const char *pngfile)
-{
-	int i;
-	FILE *fd=NULL;
-	char *orden=NULL;
-
-	if(V==NULL)		return FALSE;
-	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
-	if(pngfile==NULL)	return FALSE;
-
-	fd=fopen(octfile,"w");
-	if(fd==NULL)		return FALSE;
-	fprintf(fd,"Y1=[");
-	for(i=0 ; i<V->Nel ; i++)	fprintf(fd,"%e\t",V->V[i]);
-	fprintf(fd,"];\n");
-	fprintf(fd,"Y8=[Y1,0*Y1,0*Y1,0*Y1,0*Y1,0*Y1,0*Y1,0*Y1];\n");
-	fprintf(fd,"N=%d;\n",V->Nel);
-	fprintf(fd,"X1=[0:N-1]*2/N;\n");
-	fprintf(fd,"X8=[0:8*N-1]*2/(8*N);\n");
-	fprintf(fd,"F1=abs(fft(Y1));\n");
-	fprintf(fd,"F8=abs(fft(Y8));\n");
-	fprintf(fd,"plot(X1,F1,\'o\',X8,F8,\'--\');\n");
-	fprintf(fd,"grid on;\n");
-	fprintf(fd,"xlabel(\'[0 -> 2*pi]\');\n");
-	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
-	fprintf(fd,"\n");
-	fprintf(fd,"\n");
-	fclose(fd);
-
-	orden=(char *)calloc(1,16+strlen(octfile));
-	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
-	i=system(orden);
 
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -570,6 +539,8 @@ int pds_octplot_afft_vector8_in_png(const PdsVector *V,const char *labely,const
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -584,30 +555,55 @@ int pds_octplot_file_col_in_png(const char *datafile,int col,const char *labelx,
 	if(col<=0)		return FALSE;
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"M=load(\'%s\');\n",datafile);
 	fprintf(fd,"V=M(:,%d);\n",col);
 	fprintf(fd,"\n");
-	fprintf(fd,"N=length(V)\n");
-	fprintf(fd,"EjeX=[0:N-1]\n");
-	fprintf(fd,"plot(EjeX,V,\'o-\');\n");
+	fprintf(fd,"N=length(V);\n");
+	fprintf(fd,"X=[0:N-1];\n");
+	fprintf(fd,"plot(X,V,\'o-\');\n");
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
@@ -621,6 +617,8 @@ int pds_octplot_file_col_in_png(const char *datafile,int col,const char *labelx,
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
  *  \param[in] pngfile Nombre del archivo *.png de salida.
  *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
  *  \ingroup PdsOctPlotPngGroup
@@ -636,10 +634,24 @@ int pds_octplot_file_cols_in_png(const char *datafile,int colx,int coly,const ch
 	if(coly<=0)		return FALSE;
 	if(labelx==NULL)	return FALSE;
 	if(labely==NULL)	return FALSE;
-	if(octfile==NULL)	return FALSE;
 	if(pngfile==NULL)	return FALSE;
 
-	fd=fopen(octfile,"w");
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
 	if(fd==NULL)		return FALSE;
 	fprintf(fd,"M=load(\'%s\');\n",datafile);
 	fprintf(fd,"X=M(:,%d);\n",colx);
@@ -649,16 +661,27 @@ int pds_octplot_file_cols_in_png(const char *datafile,int colx,int coly,const ch
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"ylabel(\'%s\');\n",labely);
-	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:20\',\'-S800,600\');\n",pngfile);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S800,600\');\n",pngfile,FONTSIZE);
 	fprintf(fd,"\n");
 	fprintf(fd,"\n");
 	fclose(fd);
 
-	orden=(char *)calloc(1,16+strlen(octfile));
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
 	if(orden==NULL)	return FALSE;
-	sprintf(orden,"octave -q %s",octfile);
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
 	i=system(orden);
 
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
 	return TRUE;
 }
 
